"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toFileName = exports.resolveAnyFile = exports.writeFile = exports.readFile = void 0;
const path_1 = require("path");
const fs_1 = require("fs");
const loggin_1 = require("../loggin");
const prettier_1 = require("../prettier");
function jsonParse(str) {
    return JSON.parse(str);
}
/*
const w = readFile('path') // string
const x = readFile('path', {}) // string
const y = readFile('path', {ext: 'json'}) // {}
const z = readFile<{ n: number }>('path', {ext: 'json'}) // {n: number}
*/
/**
 * Ensures the file exists before reading it
 */
function readFile(path, cfg) {
    const { fail, ext } = Object.assign({ fail: false }, cfg);
    if (!(0, fs_1.existsSync)(path)) {
        const errorStr = `${path} does not exist.`;
        if (!fail) {
            (0, loggin_1.logVerbose)(errorStr);
            return '';
        }
        throw new Error(errorStr);
    }
    if ((0, fs_1.lstatSync)(path).isDirectory()) {
        throw new Error(`${path} is a directory but needs to be a file.`);
    }
    const fileContent = (0, fs_1.readFileSync)(path, 'utf-8');
    return ext === 'json' ? jsonParse(fileContent) : fileContent;
}
exports.readFile = readFile;
/**
 * Ensures the folder exists before writing it
 */
function writeFile(filePath, data) {
    const dir = (0, path_1.dirname)(filePath);
    if (!(0, fs_1.existsSync)(dir)) {
        (0, loggin_1.logVerbose)(`Created dir ${dir} to save ${filePath}`);
        (0, fs_1.mkdirSync)(dir);
    }
    const ext = filePath.split('.').pop() || '';
    const formattedData = (0, prettier_1.formatCode)(data, (0, prettier_1.getParserFromExtname)(ext));
    // @TODO implement a check that saves the file only if the content is different => git noise
    return (0, fs_1.writeFileSync)(filePath, formattedData);
}
exports.writeFile = writeFile;
function resolveAnyFile(path) {
    // 🔥 Live compilation of TypeScript files
    if (path.endsWith('.ts')) {
        // Register TS compiler lazily
        // tsNode needs the compilerOptions.module resolution to be 'commonjs',
        // so that imports in the `*.uf.ts` files work.
        // eslint-disable-next-line @typescript-eslint/no-var-requires
        require('ts-node').register({
            transpileOnly: true,
            compilerOptions: {
                module: 'commonjs',
                strict: false
            }
        });
    }
    // eslint-disable-next-line @typescript-eslint/no-var-requires
    const file = require(path);
    // If the user provides a configuration in TS file
    // then there are 2 cases for exporting an object. The first one is:
    // `module.exports = { ... }`. And the second one is:
    // `export default { ... }`. The ESM format is compiled into:
    // `{ default: { ... } }`
    const exports = file.default || file;
    return { exports, path };
}
exports.resolveAnyFile = resolveAnyFile;
/**
 * Upper or camelCase to lowercase hyphenated
 */
function toFileName(s) {
    return s
        .replace(/([a-z\d])([A-Z])/g, '$1_$2')
        .toLowerCase()
        .replace(/[ _]/g, '-')
        .replace(/[/\\]/g, '-');
}
exports.toFileName = toFileName;
//# sourceMappingURL=index.js.map